// Function to create a new note
function createNoteElement(note) {
    const noteElement = document.createElement('div');
    noteElement.className = 'note';

    // Create title and buttons container
    const titleButtonsContainer = document.createElement('div');
    titleButtonsContainer.className = 'title-buttons-container';

    // Create title
    const title = document.createElement('p');
    title.className = 'card__title';
    title.textContent = note.title;
    titleButtonsContainer.appendChild(title);

    // Create edit button
    const editButton = document.createElement('button');
    editButton.className = 'note-button';
    editButton.innerHTML = '<i class="fas fa-edit" aria-hidden="true"></i>'; // Font Awesome edit icon
    editButton.onclick = () => {
        document.getElementById('noteTitle').value = note.title;
        document.getElementById('noteInput').innerText = note.content; // Use innerText to handle Markdown content
        document.getElementById('saveButton').textContent = 'Update Note';
        localStorage.setItem('editingNoteId', note.id);
    };
    titleButtonsContainer.appendChild(editButton);

    // Create delete button
    const deleteButton = document.createElement('button');
    deleteButton.className = 'note-button';
    deleteButton.innerHTML = '<i class="fas fa-trash" aria-hidden="true"></i>'; // Font Awesome delete icon
    deleteButton.onclick = () => {
        // Directly delete the note without confirmation
        deleteNoteFromStorage(note.id);
        renderNotes();
    };
    titleButtonsContainer.appendChild(deleteButton);

    noteElement.appendChild(titleButtonsContainer);

    // Create date
    const date = document.createElement('p');
    date.className = 'card__date';
    date.textContent = note.date;
    noteElement.appendChild(date);

    // Render note content as HTML
    const content = document.createElement('div');
    content.innerHTML = marked.parse(note.content); // Convert Markdown to HTML
    noteElement.appendChild(content);

    return noteElement;
}

// Function to render notes
function renderNotes() {
    const noteList = document.getElementById('noteList');
    noteList.innerHTML = '';
    const notes = getNotesFromStorage();
    notes.forEach(note => {
        const noteElement = createNoteElement(note);
        noteList.appendChild(noteElement);
    });
}

// Event listener for the save button
document.getElementById('saveButton').addEventListener('click', () => {
    const title = document.getElementById('noteTitle').value;
    const content = document.getElementById('noteInput').innerText; // Use innerText to get Markdown content
    const id = localStorage.getItem('editingNoteId');
    
    if (id) {
        updateNoteInStorage(id, title, content);
        localStorage.removeItem('editingNoteId');
        document.getElementById('saveButton').textContent = 'Save Note';
    } else {
        saveNoteToStorage(title, content);
    }
    
    renderNotes(); // Re-render notes after saving
    clearTextBoxes(); // Clear text boxes and prepare for a new note
});

// Event listener for the clear button
document.getElementById('clearButton').addEventListener('click', () => {
    clearTextBoxes(); // Clear text boxes and prepare for a new note
});

// Function to clear text boxes and reset the state
function clearTextBoxes() {
    document.getElementById('noteTitle').value = '';
    document.getElementById('noteInput').innerText = ''; // Clear contenteditable div
    document.getElementById('saveButton').textContent = 'Save Note'; // Reset button text
    localStorage.removeItem('editingNoteId'); // Remove editing note ID from localStorage
    renderNotes(); // Re-render notes to ensure the state is up-to-date
}

// Helper functions to interact with local storage
function getNotesFromStorage() {
    const notes = localStorage.getItem('notes');
    return notes ? JSON.parse(notes) : [];
}

function saveNoteToStorage(title, content) {
    const notes = getNotesFromStorage();
    const id = new Date().toISOString();
    notes.push({ id, title, content, date: new Date().toLocaleDateString() });
    localStorage.setItem('notes', JSON.stringify(notes));
}

function updateNoteInStorage(id, title, content) {
    const notes = getNotesFromStorage();
    const index = notes.findIndex(note => note.id === id);
    if (index > -1) {
        notes[index] = { ...notes[index], title, content };
        localStorage.setItem('notes', JSON.stringify(notes));
    }
}

function deleteNoteFromStorage(id) {
    const notes = getNotesFromStorage();
    const filteredNotes = notes.filter(note => note.id !== id);
    localStorage.setItem('notes', JSON.stringify(filteredNotes));
}

// Initialize the notes on page load
renderNotes();
